package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.MtmMonitoringTemplateMapper;
import com.ruoyi.system.domain.MtmMonitoringTemplate;
import com.ruoyi.system.service.IMtmMonitoringTemplateService;

/**
 * 监控模板管理Service业务层处理
 * 
 * @author gyt
 * @date 2025-08-12
 */
@Service
public class MtmMonitoringTemplateServiceImpl implements IMtmMonitoringTemplateService 
{
    @Autowired
    private MtmMonitoringTemplateMapper mtmMonitoringTemplateMapper;

    /**
     * 查询监控模板管理
     * 
     * @param id 监控模板管理主键
     * @return 监控模板管理
     */
    @Override
    public MtmMonitoringTemplate selectMtmMonitoringTemplateById(Long id)
    {
        return mtmMonitoringTemplateMapper.selectMtmMonitoringTemplateById(id);
    }

    /**
     * 查询监控模板管理列表
     * 
     * @param mtmMonitoringTemplate 监控模板管理
     * @return 监控模板管理
     */
    @Override
    public List<MtmMonitoringTemplate> selectMtmMonitoringTemplateList(MtmMonitoringTemplate mtmMonitoringTemplate)
    {
        return mtmMonitoringTemplateMapper.selectMtmMonitoringTemplateList(mtmMonitoringTemplate);
    }

    /**
     * 新增监控模板管理
     * 
     * @param mtmMonitoringTemplate 监控模板管理
     * @return 结果
     */
    @Override
    public int insertMtmMonitoringTemplate(MtmMonitoringTemplate mtmMonitoringTemplate)
    {
        mtmMonitoringTemplate.setCreateTime(DateUtils.getNowDate());
        return mtmMonitoringTemplateMapper.insertMtmMonitoringTemplate(mtmMonitoringTemplate);
    }

    /**
     * 修改监控模板管理
     * 
     * @param mtmMonitoringTemplate 监控模板管理
     * @return 结果
     */
    @Override
    public int updateMtmMonitoringTemplate(MtmMonitoringTemplate mtmMonitoringTemplate)
    {
        mtmMonitoringTemplate.setUpdateTime(DateUtils.getNowDate());
        return mtmMonitoringTemplateMapper.updateMtmMonitoringTemplate(mtmMonitoringTemplate);
    }

    /**
     * 批量删除监控模板管理
     * 
     * @param ids 需要删除的监控模板管理主键
     * @return 结果
     */
    @Override
    public int deleteMtmMonitoringTemplateByIds(Long[] ids)
    {
        return mtmMonitoringTemplateMapper.deleteMtmMonitoringTemplateByIds(ids);
    }

    /**
     * 删除监控模板管理信息
     * 
     * @param id 监控模板管理主键
     * @return 结果
     */
    @Override
    public int deleteMtmMonitoringTemplateById(Long id)
    {
        return mtmMonitoringTemplateMapper.deleteMtmMonitoringTemplateById(id);
    }
}
