package com.ruoyi.system.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.domain.MtmMonitoringTemplate;
import com.ruoyi.system.service.IMtmMonitoringTemplateService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 监控模板管理Controller
 * 
 * @author gyt
 * @date 2025-08-12
 */
@RestController
@RequestMapping("/template")
public class MtmMonitoringTemplateController extends BaseController
{
    @Autowired
    private IMtmMonitoringTemplateService mtmMonitoringTemplateService;

    /**
     * 查询监控模板管理列表
     */
    @RequiresPermissions("system:template:list")
    @GetMapping("/list")
    public TableDataInfo list(MtmMonitoringTemplate mtmMonitoringTemplate)
    {
        startPage();
        List<MtmMonitoringTemplate> list = mtmMonitoringTemplateService.selectMtmMonitoringTemplateList(mtmMonitoringTemplate);
        return getDataTable(list);
    }

    /**
     * 导出监控模板管理列表
     */
    @RequiresPermissions("system:template:export")
    @Log(title = "监控模板管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MtmMonitoringTemplate mtmMonitoringTemplate)
    {
        List<MtmMonitoringTemplate> list = mtmMonitoringTemplateService.selectMtmMonitoringTemplateList(mtmMonitoringTemplate);
        ExcelUtil<MtmMonitoringTemplate> util = new ExcelUtil<MtmMonitoringTemplate>(MtmMonitoringTemplate.class);
        util.exportExcel(response, list, "监控模板管理数据");
    }

    /**
     * 获取监控模板管理详细信息
     */
    @RequiresPermissions("system:template:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(mtmMonitoringTemplateService.selectMtmMonitoringTemplateById(id));
    }

    /**
     * 新增监控模板管理
     */
    @RequiresPermissions("system:template:add")
    @Log(title = "监控模板管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MtmMonitoringTemplate mtmMonitoringTemplate)
    {
        return toAjax(mtmMonitoringTemplateService.insertMtmMonitoringTemplate(mtmMonitoringTemplate));
    }

    /**
     * 修改监控模板管理
     */
    @RequiresPermissions("system:template:edit")
    @Log(title = "监控模板管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MtmMonitoringTemplate mtmMonitoringTemplate)
    {
        return toAjax(mtmMonitoringTemplateService.updateMtmMonitoringTemplate(mtmMonitoringTemplate));
    }

    /**
     * 删除监控模板管理
     */
    @RequiresPermissions("system:template:remove")
    @Log(title = "监控模板管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mtmMonitoringTemplateService.deleteMtmMonitoringTemplateByIds(ids));
    }
}
